var pump = require('pump');
var gulp = require('gulp');
var $ = require('gulp-load-plugins')();
var bower_path = './bower_components';
var browserSync = require('browser-sync').create();

require('gulp-release-tasks')(gulp);

gulp.task('compass', function () {
    return gulp.src('./src/scss/*.scss')
        .pipe($.compass({
            config_file: './config.rb',
            css: './.temp/css',
            sass: './src/scss',
            sourcemap: true
        }))
        .on('error', function (error) {
            console.log(error.toString());
            this.emit('end');
        });
});

gulp.task('clean_copy_css', ['compass'], function () {
    return gulp.src('./.temp/css/*.css')
        .pipe($.sourcemaps.init({loadMaps: true}))
        .pipe($.cleanCss())
        .pipe($.sourcemaps.write('.'))
        .pipe(gulp.dest('./dist/css/'));
})

gulp.task('copy_fonts', function () {
    return gulp.src([
        bower_path + '/components-font-awesome/fonts/fontawesome-webfont.*',
        bower_path + '/bootstrap-sass/assets/fonts/bootstrap/*.*',
    ]).pipe(gulp.dest('dist/fonts/'));
});

gulp.task('copy_vendor_javascript', function () {
    return gulp.src([
        bower_path + '/jquery/dist/jquery.js',
        bower_path + '/bootstrap-sass/assets/javascripts/bootstrap.js',
        bower_path + '/bootstrap-sass-datepicker/js/bootstrap-sass-datepicker.js',
        bower_path + '/bootstrap-timepicker/js/bootstrap-timepicker.js',
        bower_path + '/bootstrap-touchspin/src/jquery.bootstrap-touchspin.js',
        bower_path + '/bootbox.js/bootbox.js',
        bower_path + '/jquery-mask-plugin/dist/jquery.mask.js',
        bower_path + '/remarkable-bootstrap-notify/dist/bootstrap-notify.js',
        bower_path + '/typeahead.js/dist/typeahead.bundle.js',
        bower_path + '/datatables.net/js/jquery.dataTables.js',
        bower_path + '/datatables.net-bs/js/dataTables.bootstrap.js',
        bower_path + '/jstree/dist/jstree.js'
    ]).pipe($.sourcemaps.init({loadMaps: true}))
        .pipe($.concat('vendor.js'))
        .pipe($.uglify())
        .pipe($.sourcemaps.write('.'))
        .pipe(gulp.dest('./dist/js'));
});

gulp.task('copy_image', function () {
    return gulp.src([
        bower_path + '/jstree/dist/themes/default/*.png',
        bower_path + '/jstree/dist/themes/default/*.gif'
    ]).pipe(gulp.dest('./dist/css'));
});

gulp.task('copy_json', function () {
    return gulp.src([
        'src/json/dataTable_pt-br.json'
    ]).pipe(gulp.dest('./dist/json'));
});

gulp.task('copy_javascript', function (cb) {
    pump([
        gulp.src('src/js/**/*.js'),
        $.sourcemaps.init({loadMaps: true}),
        $.concat('nti.js'),
        $.uglify(),
        $.sourcemaps.write('.'),
        gulp.dest('./dist/js')
    ], cb);
});

gulp.task('clean', function () {
    return gulp.src(['dist', '.temp'], {
        read: false
    }).pipe($.clean());
});

gulp.task('build', ['clean_copy_css', 'copy_javascript', 'copy_fonts', 'copy_json', 'copy_vendor_javascript', 'copy_image']);

gulp.task('default', ['clean'], function () {
    gulp.start('build');
});

gulp.task('watch', function () {
    gulp.watch('src/**/*.*', ['default']);
});

gulp.task('serve', function () {
    browserSync.init({
        server: "./"
    });

    gulp.watch('src/**/*.*', ['default']);
    gulp.watch("dist/**/*.*").on('change', browserSync.reload);
    gulp.watch("demo/**/*.*").on('change', browserSync.reload);
});

gulp.task('copyDist', function () {
    return gulp.src(['./**', '!./bower_components{,/**}', '!./node_modules{,/**}', '!./nti_layout.zip'
    ]).pipe(gulp.dest('./.temp/zip/nti-layout'));
});

gulp.task('zip', ['copyDist'], function () {
    return gulp.src('./.temp/zip/**')
        .pipe($.zip('nti_layout.zip'))
        .pipe(gulp.dest('./'));
});
